@@ -68,6 +68,11 @@ struct cis_hostinfo
                                    /* 1 jiffie = 1/ct_per_sec [s] */
 
 	unsigned long  ctx_swtch;
+	unsigned long  swpin;
+	unsigned long  swpout;
+
+	unsigned long  disk_read[4];
+	unsigned long  disk_write[4];
 	
 	unsigned short CPU_available;
 
@@ -107,8 +112,8 @@ struct cis_procinfo
 	unsigned long  minflt;
         unsigned long  majflt;
 
-	unsigned long  rd_bytes;
-        unsigned long  wr_bytes;
+	unsigned long  disk_read;
+        unsigned long  disk_write;
         
         void *priv;
 };
@@ -143,8 +148,8 @@ struct cis_netdevinfo
         unsigned char id;
         unsigned char status;
 
-        unsigned long rx_bytes;
-        unsigned long tx_bytes;
+        unsigned long receive;
+        unsigned long transmit;
 
         unsigned long collisions;
 
@@ -153,4 +158,12 @@ struct cis_netdevinfo
 
 #define NETDEVINFO_LEN  (OFFSET(cis_netdevinfo, priv))
 
+struct cis_lmsinfo {
+	char name[16];
+	short divider;
+	short value;
+};
+
+#define LMSINFO_LEN  (sizeof (struct cis_lmsinfo))
+
 #endif
