@@ -41,6 +41,7 @@ enum {
 #define CIS_CPU      (1<<4)
 #define CIS_IDLE     (1<<5)
 #define CIS_CTXSWTCH (1<<6)
+#define CIS_DISK     (1<<7)
 #define CIS_ALL      (-1)
 
 
@@ -139,5 +140,6 @@ int cisNdevlist (CLIENT *handle,
 		 struct in_addr addr,
 		 float interval);
 
+int cisLMsensors(CLIENT *handle, struct cis_lmsinfo **list, struct in_addr addr);
 /* end of client calls */
 #endif
