@@ -64,8 +64,8 @@ int read_netdevlist(char *buffer, char **start, off_t offset, int length, int du
 
                 msg.status = dev->start;
 		strncpy(msg.name, dev->name, IFNAMSIZ);
-                msg.rx_bytes = stats->rx_bytes;
-                msg.tx_bytes = stats->tx_bytes;
+                msg.receive = stats->rx_bytes >> 10;
+                msg.transmit = stats->tx_bytes >> 10;
                 msg.collisions = stats->collisions;
                 
 
@@ -114,9 +114,9 @@ static int netmon_msg(struct device *dev, unsigned char action)
                 msg->status = action;
                 strncpy (msg->name, dev->name, IFNAMSIZ);
 
-                msg->rx_bytes   = (stats) ? stats->rx_bytes : 0;
-                msg->tx_bytes   = (stats) ? stats->tx_bytes : 0;
-                msg->collisions = (stats) ? stats->collisions : 0;
+                msg->receive    = (stats) ? stats->rx_bytes >> 10 : 0;
+                msg->transmit   = (stats) ? stats->tx_bytes >> 10 : 0;
+		msg->collisions = (stats) ? stats->collisions : 0;
 
                 netlink_broadcast(nmsk, outskb, 0, ~0, GFP_KERNEL);
         }
