@@ -84,10 +84,10 @@ int read_proclist(char *buffer, char **start, off_t offset, int length, int dumm
                 p.stime      = tsk->times.tms_stime;
                 p.minflt     = tsk->min_flt;
                 p.majflt     = tsk->maj_flt;
-                p.rss        = tsk->mm->rss << PAGE_SHIFT;
-                p.vm         = tsk->mm->total_vm << PAGE_SHIFT;
-                p.rd_bytes   = tsk->rd_bytes;
-                p.wr_bytes   = tsk->wr_bytes;
+                p.rss        = tsk->mm->rss << (PAGE_SHIFT - 10);
+                p.vm         = tsk->mm->total_vm << (PAGE_SHIFT - 10);
+                p.disk_read  = tsk->rd_bytes >> 10;
+                p.disk_write = tsk->wr_bytes >> 10;
                 
                 memcpy (p.cmd, tsk->comm, 16);
 
@@ -140,10 +140,10 @@ static int procmon_msg(int pid, unsigned char event)
                         msg->stime      = tsk->times.tms_stime;
                         msg->minflt     = tsk->min_flt;
                         msg->majflt     = tsk->maj_flt;
-                        msg->rss        = tsk->mm->rss << PAGE_SHIFT;
-                        msg->vm         = tsk->mm->total_vm << PAGE_SHIFT;
-			msg->rd_bytes   = tsk->rd_bytes;
-			msg->wr_bytes   = tsk->wr_bytes;
+                        msg->rss        = tsk->mm->rss << (PAGE_SHIFT - 10);
+                        msg->vm         = tsk->mm->total_vm << (PAGE_SHIFT - 10);
+			msg->disk_read  = tsk->rd_bytes >> 10;
+			msg->disk_write = tsk->wr_bytes >> 10;
                         memcpy (msg->cmd, tsk->comm, 16);
                 }
 
