@@ -33,7 +33,7 @@
 
 #include "cis.h"
 #include "cis_xdr.h"
-#include "cis_srv.h"
+#include "cisd.h"
 #include "cis_clnt.h"
 
 #define OFFSET(str, el)  (int) &(((struct str *) 0)->el)
@@ -117,7 +117,7 @@ static int netdev_cmp(const void *l, const void *r)
 
 static bool_t xdr_hostlist(XDR *handle, struct cis_hostinfo **listp)
 {
-	int length = 0;
+	int i, length = 0;
 	struct cis_hostinfo *new_list, *hi;
 
         list_length = 0;
@@ -147,6 +147,17 @@ static bool_t xdr_hostlist(XDR *handle, struct cis_hostinfo **listp)
 			return (FALSE);
 		if (!xdr_u_long(handle, &hi->ctx_swtch))
 			return (FALSE);
+		if (!xdr_u_long(handle, &hi->swpin))
+			return (FALSE);
+		if (!xdr_u_long(handle, &hi->swpout))
+			return (FALSE);
+		for (i = 0; i < 4; i++)
+			if (!xdr_u_long(handle, &hi->disk_read[i]))
+				return (FALSE);
+		for (i = 0; i < 4; i++)
+			if (!xdr_u_long(handle, &hi->disk_write[i]))
+				return (FALSE);
+
 	}
 
         list_length = length;
@@ -180,6 +191,8 @@ static bool_t xdr_list_req(XDR *handle, struct list_req *req)
 
 static bool_t xdr_host_rep(XDR *handle, struct cis_hostinfo *hi)
 {
+	int i;
+	
         if (!xdr_char(handle, &hi->status))
                 return (FALSE);
 
@@ -192,6 +205,17 @@ static bool_t xdr_host_rep(XDR *handle, struct cis_hostinfo *hi)
 	if (!xdr_u_long(handle, &hi->ctx_swtch))
 		return (FALSE);
 
+	if (!xdr_u_long(handle, &hi->swpin))
+		return (FALSE);
+	if (!xdr_u_long(handle, &hi->swpout))
+		return (FALSE);
+	for (i = 0; i < 4; i++)
+		if (!xdr_u_long(handle, &hi->disk_read[i]))
+			return (FALSE);
+	for (i = 0; i < 4; i++)
+		if (!xdr_u_long(handle, &hi->disk_write[i]))
+			return (FALSE);
+
         return (TRUE);
 }
 
@@ -218,10 +242,10 @@ static bool_t xdr_hosts_update_req(XDR *handle, struct cis_hostinfo **hi)
 
 static bool_t xdr_hosts_update_reply(XDR *handle, struct cis_hostinfo **hinfo)
 {
-        int i;
+        int i, j;
         struct cis_hostinfo *hi;
 
-        for (i = 0; i < list_length; i++, hinfo++) {
+	for (j = 0; j < list_length; j++, hinfo++) {
                 hi = *hinfo;
                 if (!hi->addr.s_addr)
                         continue;
@@ -260,7 +284,11 @@ static bool_t xdr_hosts_update_reply(XDR *handle, struct cis_hostinfo **hinfo)
                                 return (FALSE);
                         if (!xdr_u_long(handle, &hi->freeswap))
                                 return (FALSE);
-                }
+			if (!xdr_u_long(handle, &hi->swpin))
+				return (FALSE);
+			if (!xdr_u_long(handle, &hi->swpout))
+				return (FALSE);
+                 }
                 
                 if (update_code & CIS_CPU)
                         if (!xdr_u_short(handle, &hi->CPU_available))
@@ -272,7 +300,18 @@ static bool_t xdr_hosts_update_reply(XDR *handle, struct cis_hostinfo **hinfo)
 
 		if (update_code & CIS_CTXSWTCH)
                         if (!xdr_u_long(handle, &hi->ctx_swtch))
-                                return (FALSE);
+				return (FALSE);
+
+		if (update_code & CIS_DISK) {
+			for (i = 0; i < 4; i++) {
+				if (!xdr_u_long(handle, &hi->disk_read[i]))
+					return (FALSE);
+			}
+			for (i = 0; i < 4; i++) {
+				if (!xdr_u_long(handle, &hi->disk_write[i]))
+					return (FALSE);
+			}
+		}
         }
 
         return (TRUE);
@@ -315,10 +354,10 @@ static bool_t xdr_proc_reply(XDR *handle, struct cis_procinfo **listp)
 		if (!xdr_u_long(handle, &p->majflt))
                         return (FALSE);
 
-		if (!xdr_u_long(handle, &p->rd_bytes))
+		if (!xdr_u_long(handle, &p->disk_read))
                         return (FALSE);
 
-		if (!xdr_u_long(handle, &p->wr_bytes))
+		if (!xdr_u_long(handle, &p->disk_write))
                         return (FALSE);
 
 //                p->flags = CONSISTENT;
@@ -421,6 +460,42 @@ static bool_t xdr_netdev_reply(XDR *handle, struct cis_netdevinfo **listp)
         return (TRUE);
 }
 
+static bool_t xdr_lmsensors(XDR *handle, struct cis_lmsinfo **listp)
+{
+	int length = 0;
+	struct cis_lmsinfo *new_list;
+
+        list_length = 0;
+	cis_result = 0;
+
+	if (!xdr_int(handle, &length))
+                return (FALSE);
+
+        if (!length)
+                return (TRUE);
+
+	if (length < 0) {
+		cis_result = length;
+		return (TRUE);
+	}
+
+	free(*listp);
+	*listp = NULL;
+
+	if (!(new_list = calloc(length, sizeof (struct cis_lmsinfo))))
+		return (FALSE);
+	*listp = new_list;
+
+	if (!xdr_vector(handle, (char *) new_list, length,
+			sizeof(struct cis_lmsinfo), (xdrproc_t) xdr_lmsinfo))
+		return (FALSE);
+
+        list_length = length;
+
+        return (TRUE);
+}
+
+
 /*
  * Interface calls
  */
@@ -649,3 +724,32 @@ int cisNdevlist(CLIENT *handle, struct cis_netdevinfo **list, struct in_addr add
 	return list_length;
 }
 
+int cisLMsensors(CLIENT *handle, struct cis_lmsinfo **list, struct in_addr addr)
+{
+        int err;
+        *list = NULL;
+
+        cis_errno = 0;
+	
+	if (!handle) {
+                cis_errno = CIS_NOCONN;
+                return -1;
+	}
+
+	err = clnt_call(handle, LM_SENSORS,
+			(xdrproc_t) xdr_inaddr,    (caddr_t) &addr,
+                        (xdrproc_t) xdr_lmsensors, (caddr_t) list,
+                        cis_timeout);
+	if (err) {
+		cis_errno = err;
+		return -1;
+	}
+	
+	if (cis_result != HOST_AVAILABLE) {
+                cis_errno = cis_result;
+		return -1;
+	}
+	
+	return list_length;
+}
+
