@@ -57,6 +57,16 @@ struct description cis_hostinfo_desc[] = {
         {ELEMENT(cis_hostinfo, totalswap),     1},
         {ELEMENT(cis_hostinfo, freeswap),      1},
         {ELEMENT(cis_hostinfo, ctx_swtch),     1},
+        {ELEMENT(cis_hostinfo, swpin),         1},
+        {ELEMENT(cis_hostinfo, swpout),        1},
+	{ELEMENT(cis_hostinfo, disk_read[0]),  1},
+	{ELEMENT(cis_hostinfo, disk_read[1]),  1},
+	{ELEMENT(cis_hostinfo, disk_read[2]),  1},
+	{ELEMENT(cis_hostinfo, disk_read[3]),  1},
+	{ELEMENT(cis_hostinfo, disk_write[0]), 1},
+	{ELEMENT(cis_hostinfo, disk_write[1]), 1},
+	{ELEMENT(cis_hostinfo, disk_write[2]), 1},
+	{ELEMENT(cis_hostinfo, disk_write[3]), 1},
         {ELEMENT(cis_hostinfo, status),        1},
         {ELEMENT(cis_hostinfo, CPU_available), 1},
         {ELEMENT(cis_hostinfo, reliability),   1},
@@ -66,18 +76,18 @@ struct description cis_hostinfo_desc[] = {
 #define cis_hostinfo_desclen (sizeof (cis_hostinfo_desc)/sizeof (struct description))
 
 struct description cis_procinfo_desc[] = {
-        {ELEMENT(cis_procinfo, pid),      PROCINFO_LEN},
-        {ELEMENT(cis_procinfo, ppid),     SIZE(cis_procinfo, ppid)},
-        {ELEMENT(cis_procinfo, cmd),      SIZE(cis_procinfo, cmd)},
-        {ELEMENT(cis_procinfo, priority), 1},
-        {ELEMENT(cis_procinfo, utime),    1},
-        {ELEMENT(cis_procinfo, stime),    1},
-        {ELEMENT(cis_procinfo, rss),      1},
-        {ELEMENT(cis_procinfo, vm),       1},
-        {ELEMENT(cis_procinfo, pCPU),     1},
-        {ELEMENT(cis_procinfo, majflt),   1},
-        {ELEMENT(cis_procinfo, rd_bytes), 1},
-        {ELEMENT(cis_procinfo, wr_bytes), 1},
+        {ELEMENT(cis_procinfo, pid),        PROCINFO_LEN},
+        {ELEMENT(cis_procinfo, ppid),       SIZE(cis_procinfo, ppid)},
+        {ELEMENT(cis_procinfo, cmd),        SIZE(cis_procinfo, cmd)},
+        {ELEMENT(cis_procinfo, priority),   1},
+        {ELEMENT(cis_procinfo, utime),      1},
+        {ELEMENT(cis_procinfo, stime),      1},
+        {ELEMENT(cis_procinfo, rss),        1},
+        {ELEMENT(cis_procinfo, vm),         1},
+        {ELEMENT(cis_procinfo, pCPU),       1},
+        {ELEMENT(cis_procinfo, majflt),     1},
+        {ELEMENT(cis_procinfo, disk_read),  1},
+        {ELEMENT(cis_procinfo, disk_write), 1},
 };
 
 #define cis_procinfo_desclen (sizeof (cis_procinfo_desc)/sizeof (struct description))
@@ -93,8 +103,8 @@ struct description cis_sockinfo_desc[] = {
 struct description cis_netdevinfo_desc[] = {
         {ELEMENT(cis_netdevinfo, name),       NETDEVINFO_LEN},
         {ELEMENT(cis_netdevinfo ,status),     1},
-        {ELEMENT(cis_netdevinfo ,rx_bytes),   1},
-        {ELEMENT(cis_netdevinfo ,tx_bytes),   1},
+        {ELEMENT(cis_netdevinfo ,receive),    1},
+        {ELEMENT(cis_netdevinfo ,transmit),   1},
         {ELEMENT(cis_netdevinfo ,collisions), 1},
 };
 
