@@ -187,9 +187,9 @@ bool_t xdr_netdev(XDR *handle, struct cis_netdevinfo *dev)
         if (!xdr_string(handle, &tmp, CIS_DEVNAMELEN))
                 return (FALSE);
 
-        if (!xdr_u_long(handle, &dev->rx_bytes))
+        if (!xdr_u_long(handle, &dev->receive))
                 return (FALSE);
-        if (!xdr_u_long(handle, &dev->tx_bytes))
+        if (!xdr_u_long(handle, &dev->transmit))
                 return (FALSE);
         if (!xdr_u_long(handle, &dev->collisions))
                 return (FALSE);
@@ -210,3 +210,18 @@ bool_t xdr_netdev_desc(XDR *handle, struct cis_netdevinfo *dev)
         return (TRUE);
 }
 
+bool_t xdr_lmsinfo(XDR *handle, struct cis_lmsinfo *s)
+{
+	char *tmp = s->name;
+
+	if (!xdr_string(handle, &tmp, 16))
+		return (FALSE);
+
+	if (!xdr_short(handle, &s->divider))
+		return (FALSE);
+	if (!xdr_short(handle, &s->value))
+		return (FALSE);
+	
+	return (TRUE);
+}
+
