@@ -47,6 +47,13 @@ char *sock_types[] = {
         "datagram",
 };
 
+char *disk_types[] = {
+        "hd1",
+        "hd2",
+        "hd3",
+        "hd4",
+};
+
 extern int h_errno;
 
 
@@ -128,12 +135,13 @@ int tprintf (char *fmt, ...)
 	return len;
 }
 
-
 #define SI_PRINT(el, fmt) tprintf (fmt, n->el)
 #define SI_CHPRINT(el, fmt) if (!o || o->el != n->el) SI_PRINT (el, fmt)
 
 void print_hostinfo (struct cis_hostinfo *o, struct cis_hostinfo *n)
 {
+	int i;
+	
 	if (n->status != HOST_AVAILABLE)
 		return;
 
@@ -145,11 +153,11 @@ void print_hostinfo (struct cis_hostinfo *o, struct cis_hostinfo *n)
 //                printf ( "        no change\n");
                 return;
         }
-        
+
 	SI_CHPRINT (idle,     "Idle time              %ld");
 	SI_CHPRINT (procnum,  "Number of processes    %d");
 	
-        if (!o || o->loads[0] != n->loads[0])
+	if (!o || o->loads[0] != n->loads[0])
 		tprintf("Average load in 1  min %-5.2f", n->loads[0]/100.);
         if (!o || o->loads[1] != n->loads[1])
 		tprintf("Average load in 5  min %-5.2f", n->loads[1]/100.);
@@ -163,8 +171,14 @@ void print_hostinfo (struct cis_hostinfo *o, struct cis_hostinfo *n)
         SI_CHPRINT (cachedram,"Cached memory          %ld");
         SI_CHPRINT (totalswap,"Total swap             %ld");
         SI_CHPRINT (freeswap, "Free swap              %ld");
+        SI_CHPRINT (swpin,    "Swap in rate           %ld");
+        SI_CHPRINT (swpout,   "Swap out rate          %ld");
         SI_CHPRINT (ctx_swtch,"Context switch rate    %ld");
 
+	for (i = 0; i < 4; i++)
+		if (!o || o->disk_read[i] != n->disk_read[i] || o->disk_write[i] != n->disk_write[i])
+			tprintf("Disk %s read/write   %d/%d", disk_types[i], n->disk_read[i], n->disk_write[i]);
+
         if (!o || o->CPU_available != n->CPU_available)
 		tprintf ( "CPU available [%%]      %4.2f ", n->CPU_available / 1e2);
 }
@@ -219,8 +233,8 @@ void print_procinfo_changes (struct cis_procinfo *oldtab, int nold, struct cis_p
                                 q->pid, q->cmd, q->pCPU / 1e2);
 
 		PI_CHPRINT(majflt,    "major faults    %-5ld");
-		PI_CHPRINT(rd_bytes,  "disk read rate  %-5ld");
-		PI_CHPRINT(wr_bytes,  "disk write rate %-5ld");
+		PI_CHPRINT(disk_read, "disk read rate  %-5ld");
+		PI_CHPRINT(disk_write,"disk write rate %-5ld");
                         
                 p++;
                 q++;
@@ -308,7 +322,7 @@ void print_devinfo_full (struct cis_netdevinfo *tab, int len)
 		tprintf ("%-15s %-4s rx:%10ld tx:%10ld coll:%10ld",
 			 d->name,
 			 d->status ? "up" : "down",
-			 d->rx_bytes, d->tx_bytes, d->collisions);
+			 d->receive, d->transmit, d->collisions);
 }
 
 void print_devinfo_changes (struct cis_netdevinfo *oldtab, int nold, struct cis_netdevinfo *newtab, int nnew)
@@ -326,7 +340,7 @@ void print_devinfo_changes (struct cis_netdevinfo *oldtab, int nold, struct cis_
 			tprintf ("New     %-15s %-4s rx:%10ld tx:%10ld coll:%10ld",
 				 n->name,
 				 n->status ? "up" : "down",
-				 n->rx_bytes, n->tx_bytes, n->collisions);
+				 n->receive, n->transmit, n->collisions);
 
                         n++;
                         continue;
@@ -335,7 +349,7 @@ void print_devinfo_changes (struct cis_netdevinfo *oldtab, int nold, struct cis_
                     (n == newtab+nnew || strcmp (o->name, n->name) < 0)) {
 			tprintf ("Closed  %-15s rx:%10ld tx:%10ld coll:%10ld",
 				 o->name,
-				 o->rx_bytes, o->tx_bytes, o->collisions);
+				 o->receive, o->transmit, o->collisions);
                         o++;
                         continue;
                 }
@@ -344,8 +358,8 @@ void print_devinfo_changes (struct cis_netdevinfo *oldtab, int nold, struct cis_
 			tprintf ("Changed     %-15s status          %-4s",
 				 n->name, n->status ? "up" : "down");
 
-		DI_CHPRINT(rx_bytes,  "receive rate    %-5ld");
-		DI_CHPRINT(tx_bytes,  "send rate       %-5ld");
+		DI_CHPRINT(receive,   "receive rate    %-5ld");
+		DI_CHPRINT(transmit,  "transmit rate   %-5ld");
 		DI_CHPRINT(collisions,"collisions rate %-5ld");
 
                 o++;
